#!/bin/bash
# Copyright (c) 2022 Omada Community Developers
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.

# Omada Controller installer sources: https://community.tp-link.com/en/business/forum/topic/548752
# Linux:            https://static.tp-link.com/upload/software/2022/202207/20220729/Omada_SDN_Controller_v5.4.6_Linux_x64.tar.gz

# Omada Software Controller sources URL
OMADAURL="https://static.tp-link.com/upload/software/2022/202207/20220729/Omada_SDN_Controller_v5.4.6_Linux_x64.tar.gz" && echo "URL set: ${OMADAURL}"
# jsvc source URL from Apache Download Center
JSVCURL="https://dlcdn.apache.org/commons/daemon/source/commons-daemon-1.3.1-src.tar.gz"
# Folders where sources will be downloaded
OMADASOURCES="/opt/tplink-sources"
APACHESOURCES="/opt/dlcdn.apache.org"
SWAPSIZE="1G"

# do not edit following vars if you do not know what you do:
OMADATARGZ=$(echo "${OMADAURL}" | awk '{split($0,a,"/"); print a[9]}') && echo "Omada installer filename set: ${OMADATARGZ}"
MYINSTALLERFOLDER=$(echo "${OMADATARGZ}" | sed 's/\.tar\.gz//') && echo "Omada install folder set: ${MYINSTALLERFOLDER}"
MYOMADAVERSION=$(echo "${OMADATARGZ}" | awk '{split($0,a,"_"); print a[4]}') && echo "Omada version: ${MYOMADAVERSION}"

# 1. Create swap file, then restart/reboot your instance (As on red hat 8 enterprise we run out of memory on instance type with 1Gb or lower, you can skip this step if you have 2GB+ RAM)
fallocate -l ${SWAPSIZE} /swapfile
chmod 600 /swapfile
mkswap /swapfile
swapon /swapfile
cat <<EOF_fstab | tee -a /etc/fstab
/swapfile 	swap 	swap 	defaults 	0 	0
EOF_fstab
cat <<EOF_sysctl | tee -a /etc/sysctl.conf
vm.swappiness=10
EOF_sysctl

# Install MongoDB
rpm --import https://www.mongodb.org/static/pgp/server-4.4.asc
zypper addrepo --gpgcheck "https://repo.mongodb.org/zypper/suse/15/mongodb-org/4.4/x86_64/" mongodb

# 3. upgrade system then install omada dependencies (mongodb, curl, java11, jsvc build and compilation dependencies)
zypper update -y && zypper -n install -y curl java-11-openjdk-devel mongodb-org autoconf make gcc

# 4. Compile and install jsvc
mkdir -p ${APACHESOURCES} && cd ${APACHESOURCES}
# download source
wget -c ${JSVCURL} -O - | tar -xz 
# configure and compile
cd commons-daemon-1.3.1-src/src/native/unix
sh support/buildconf.sh
# "/usr/lib64/jvm/java-11-openjdk-11" is the default installation path of OpenJDK-11 on Suse Enterprise 15.
./configure --with-java=/usr/lib64/jvm/java-11-openjdk-11
make
# Create a soft link from your JSVC path
ln -s ${APACHESOURCES}/commons-daemon-1.3.1-src/src/native/unix/jsvc /usr/bin/

# 5. download and install omada installer
mkdir -p ${OMADASOURCES} && cd ${OMADASOURCES}
wget -c ${OMADAURL} -O - | tar -xz 
# Make scripts and binaries executable    
chmod +x ${MYINSTALLERFOLDER}/*.sh
chmod +x ${MYINSTALLERFOLDER}/bin/*

# Install omada controller, by default it is enabled on boot
cd ${MYINSTALLERFOLDER}
./install.sh -y
